#! /bin/sh
#-----------------------------------------------------------------
#Shell script to delete user not logged for a long time
#-----------------------------------------------------------------
. /etc/sysconfig/clement
LOCK=/tmp/expire.sh.$APPNAME-$VERS.lock
trap "rm -f $LOCK ; exit 1" 1 2 3 15
lockfile -1 $LOCK
#-----------------------------------------------------------------
#setting local ownership
USER=`ls -l $BASE/usr/bin/$APPNAME | tr -s ' ' | cut -d' ' -f3`
GROUP=`ls -l $BASE/usr/bin/$APPNAME | tr -s ' ' | cut -d' ' -f4`
MUID=`id -u $USER`
MGID=`id -g $GROUP`
#-----------------------------------------------------------------
#domain to be covered
DOMS="domain1.com domain2.com"
#too old  time (in day)
TOOOLD=30
RESULT=/tmp/expire.sh.$$
LOG=/var/spool/$APPNAME-$VERS/logs/expire.`date +%Y%m%d`.jrl
#-----------------------------------------------------------------
#to remove an old user
do_efface()

{
echo "removing account dom="$dom "user="$1 >> $LOG
grep -v -w ^$usr .passwd > .passwd.new
if [ `id -u` = 0 ]; then  #are we root
  chown $USER.$USER .passwd.new
  fi
chmod 0644 .passwd.new
mv -f .passwd.new .passwd
rm -fr $MAILSDOM/$1
rm -fr $OWMDOM/$1
}
#-----------------------------------------------------------------
#to creat missing user
do_create()

{
if [ ! -d $MAILSDOM/$1 ] ; then 
  echo "adding account dom="$dom "user="$1 >> $LOG
  mkdir -p $MAILSDOM/$1
  chown $USER.$GROUP $MAILSDOM/$1
  fi
if [ ! -d $OWMDOM/$1 ] ; then 
  echo "adding account OWM="$dom "user="$1 >> $LOG
  mkdir -p $OWMDOM/$1
  chown mail.nobody $OWMDOM/$1
  fi
}
#-----------------------------------------------------------------
#to align directory entries with password file.
#$1 directory name
do_aligne()

{
cd $1 
echo "Checking $1 alignment" >> $LOG
ls -1 | sort > /tmp/z2.$$
for usr in `diff /tmp/z1.$$ /tmp/z2.$$ | grep '>' | cut -d' ' -f2`
  do
  echo "deleting dir="$1 "user="$usr"  directory" >> $LOG
  rm -fr $usr
  done
rm -f /tmp/z2.$$
}
#-----------------------------------------------------------------
touch $LOG
chown $USER.$USER $LOG
for dom in $DOMS 
  do
  MAILSDOM=/var/spool/$APPNAME-$VERS/mails/$dom
  OWMDOM=/var/spool/$APPNAME-$VERS/owmboxes/$dom
  if [ -d $MAILSDOM ] ; then 
    cd $MAILSDOM
    echo "scanning for old user " `date +%H:%M:%S` >> $LOG
    find . -maxdepth 1 -type d -mtime +$TOOOLD | cut -d'/' -f2 > $RESULT
    for usr in `cat $RESULT` 
      do
      case "$usr" in 
	"info"		| \
	"abuse"		| \
	"postmaster"	)
				#keeping some specific users
	  ;;
        "*"		)
          do_efface $usr	#removing others
	  ;;
        esac
      done
    rm -f $RESULT
    echo "scanning for old user " `date +%H:%M:%S` >> $LOG
    for usr in `cat .passwd | cut -d':' -f1` 
      do
      do_create $usr
      done
    fi
  cat .passwd | cut -d':' -f1 | sort > /tmp/z1.$$
  do_aligne $OWMDOM
  do_aligne $MAILSDOM
  rm -f /tmp/z1.$$
  done
#-----------------------------------------------------------------
#exiting
rm -f $LOCK
exit 0
